@@ -97,24 +97,24 @@ apply_nest_asyncio()
 def _get_rdkit_mol_from_uuid(calculation_uuid: str) -> RdkitMol:
     stjames_mol_dict = rowan.Calculation.retrieve(calculation_uuid)["molecules"][-1]
 
-    return Chem.MolFromXYZBlock(stjames.Molecule(**stjames_mol_dict).to_xyz())
+    return Chem.MolFromXYZBlock(stjames.Molecule(**stjames_mol_dict).to_xyz())  # type: ignore [attr-defined]
 
 
 def _embed_rdkit_mol(rdkm: RdkitMol) -> RdkitMol:
     try:
-        AllChem.SanitizeMol(rdkm)  # type: ignore [attr-defined]
+        AllChem.SanitizeMol(rdkm)
     except Exception as e:
         raise ValueError("Molecule could not be generated -- invalid chemistry!") from e
 
-    rdkm = AllChem.AddHs(rdkm)  # type: ignore [attr-defined]
+    rdkm = AllChem.AddHs(rdkm)
     try:
-        assert AllChem.EmbedMolecule(rdkm, maxAttempts=200) >= 0  # type: ignore [attr-defined]
+        assert AllChem.EmbedMolecule(rdkm, maxAttempts=200) >= 0
     except AssertionError as e:
-        status1 = AllChem.EmbedMolecule(rdkm, maxAttempts=200, useRandomCoords=True)  # type: ignore [attr-defined]
+        status1 = AllChem.EmbedMolecule(rdkm, maxAttempts=200, useRandomCoords=True)
         if status1 < 0:
             raise ValueError("Cannot embed molecule!") from e
     try:
-        assert AllChem.MMFFOptimizeMolecule(rdkm, maxIters=200) >= 0  # type: ignore [attr-defined]
+        assert AllChem.MMFFOptimizeMolecule(rdkm, maxIters=200) >= 0  # type: ignore [call-arg]
     except AssertionError:
         pass
 
@@ -461,9 +461,9 @@ async def _single_energy(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:
+    if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:
+        if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -473,7 +473,7 @@ async def _single_energy(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()
+        cid = conformer.GetId()   # type: ignore [call-arg]
         stjames_mol = _rdkit_to_stjames(mol, cid)
         post = rowan.Workflow.submit(
             name=name,
@@ -601,9 +601,9 @@ async def _single_optimize(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:
+    if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:
+        if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -615,7 +615,7 @@ async def _single_optimize(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()
+        cid = conformer.GetId()  # type: ignore [call-arg]
         stjames_mol = _rdkit_to_stjames(mol, cid)
 
         post = rowan.Workflow.submit(
@@ -651,7 +651,7 @@ async def _single_optimize(
     energies = [cacluation["molecules"][-1]["energy"] for cacluation in calculations]
 
     for i, conformer in enumerate(optimized_mol.GetConformers()):
-        conformer.SetPositions(np.array(optimized_positions[i]))
+        conformer.SetPositions(np.array(optimized_positions[i]))   # type: ignore [attr-defined]
 
     return {
         "molecule": mol,
@@ -764,9 +764,9 @@ async def _single_conformers(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:
+    if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:
+        if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -823,12 +823,12 @@ async def _single_conformers(
     lowest_n_uuids = [item[1][0] for item in sorted_data[:num_conformers]]
     lowest_energies = [item[0] for item in sorted_data[:num_conformers]]
 
-    AllChem.EmbedMultipleConfs(mol, numConfs=num_conformers)  # type: ignore [attr-defined]
+    AllChem.EmbedMultipleConfs(mol, numConfs=num_conformers)
 
     for i, conformer in enumerate(mol.GetConformers()):
         atoms = rowan.Calculation.retrieve(lowest_n_uuids[i])["molecules"][-1]["atoms"]
         pos = [atom["position"] for atom in atoms]
-        conformer.SetPositions(np.array(pos))
+        conformer.SetPositions(np.array(pos))  # type: ignore [attr-defined]
 
     return {
         "molecule": mol,
@@ -918,9 +918,9 @@ async def _single_charges(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:
+    if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:
+        if mol.GetNumConformers() == 0:   # type: ignore [call-arg]
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -930,7 +930,7 @@ async def _single_charges(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()
+        cid = conformer.GetId()  # type: ignore [call-arg]
 
         post = rowan.Workflow.submit(
             name=name,
